## [{{ version }}] - {{ date }}
{% if sections.added %}

### {{ section_names.added }}
{% for item in sections.added -%}
- {{ item.message }}{% if include_links and item.hash %} ([{{ item.hash[:7] }}]({{ repo_url }}/commit/{{ item.hash }})){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.changed %}

### {{ section_names.changed }}
{% for item in sections.changed -%}
- {{ item.message }}{% if include_links and item.hash %} ([{{ item.hash[:7] }}]({{ repo_url }}/commit/{{ item.hash }})){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.deprecated %}

### {{ section_names.deprecated }}
{% for item in sections.deprecated -%}
- {{ item.message }}{% if include_links and item.hash %} ([{{ item.hash[:7] }}]({{ repo_url }}/commit/{{ item.hash }})){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.removed %}

### {{ section_names.removed }}
{% for item in sections.removed -%}
- {{ item.message }}{% if include_links and item.hash %} ([{{ item.hash[:7] }}]({{ repo_url }}/commit/{{ item.hash }})){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.fixed %}

### {{ section_names.fixed }}
{% for item in sections.fixed -%}
- {{ item.message }}{% if include_links and item.hash %} ([{{ item.hash[:7] }}]({{ repo_url }}/commit/{{ item.hash }})){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.security %}

### {{ section_names.security }}
{% for item in sections.security -%}
- {{ item.message }}{% if include_links and item.hash %} ([{{ item.hash[:7] }}]({{ repo_url }}/commit/{{ item.hash }})){% endif %}
{% endfor %}
{%- endif %}
