## What's Changed in {{ version }}
{% if sections.added %}

### ✨ New Features
{% for item in sections.added -%}
* {{ item.message }}{% if include_links and item.hash %} ({{ item.hash[:7] }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.changed %}

### 🔄 Changes
{% for item in sections.changed -%}
* {{ item.message }}{% if include_links and item.hash %} ({{ item.hash[:7] }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.fixed %}

### 🐛 Bug Fixes
{% for item in sections.fixed -%}
* {{ item.message }}{% if include_links and item.hash %} ({{ item.hash[:7] }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.security %}

### 🔒 Security
{% for item in sections.security -%}
* {{ item.message }}{% if include_links and item.hash %} ({{ item.hash[:7] }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.deprecated %}

### ⚠️ Deprecated
{% for item in sections.deprecated -%}
* {{ item.message }}{% if include_links and item.hash %} ({{ item.hash[:7] }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.removed %}

### 🗑️ Removed
{% for item in sections.removed -%}
* {{ item.message }}{% if include_links and item.hash %} ({{ item.hash[:7] }}){% endif %}
{% endfor %}
{%- endif %}

**Full Changelog**: {{ repo_url }}/compare/{{ from_tag }}...{{ to_tag }}
