# {{ version }} - {{ date }}
{% for item in sections.added -%}
+ {{ item.message }}
{% endfor %}
{%- for item in sections.changed -%}
~ {{ item.message }}
{% endfor %}
{%- for item in sections.fixed -%}
* {{ item.message }}
{% endfor %}
{%- for item in sections.removed -%}
- {{ item.message }}
{% endfor %}
{%- for item in sections.deprecated -%}
! {{ item.message }}
{% endfor %}
{%- for item in sections.security -%}
# {{ item.message }}
{% endfor %}
