## {{ version }} ({{ date }})
{% if sections.added %}

#### Added
{% for item in sections.added -%}
- {{ item.message }}{% if include_links and item.hash %} · [{{ item.hash[:7] }}]({{ repo_url }}/-/commit/{{ item.hash }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.changed %}

#### Changed
{% for item in sections.changed -%}
- {{ item.message }}{% if include_links and item.hash %} · [{{ item.hash[:7] }}]({{ repo_url }}/-/commit/{{ item.hash }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.fixed %}

#### Fixed
{% for item in sections.fixed -%}
- {{ item.message }}{% if include_links and item.hash %} · [{{ item.hash[:7] }}]({{ repo_url }}/-/commit/{{ item.hash }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.security %}

#### Security
{% for item in sections.security -%}
- {{ item.message }}{% if include_links and item.hash %} · [{{ item.hash[:7] }}]({{ repo_url }}/-/commit/{{ item.hash }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.deprecated %}

#### Deprecated
{% for item in sections.deprecated -%}
- {{ item.message }}{% if include_links and item.hash %} · [{{ item.hash[:7] }}]({{ repo_url }}/-/commit/{{ item.hash }}){% endif %}
{% endfor %}
{%- endif %}
{%- if sections.removed %}

#### Removed
{% for item in sections.removed -%}
- {{ item.message }}{% if include_links and item.hash %} · [{{ item.hash[:7] }}]({{ repo_url }}/-/commit/{{ item.hash }}){% endif %}
{% endfor %}
{%- endif %}
